==> ui-framework-4.14.2-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractHtmlViewerExamplesMold.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractHtmlViewerExamplesMold<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _7_1_1293588351 _7_1_1293588351;
	public HtmlViewerExamplesMold._7_1_1293588351. _8_2_0698354864 _8_2_0698354864;
	public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864. _9_3_0308355687 _9_3_0308355687;
	public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864. _10_3_01261384254 _10_3_01261384254;
	public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864._10_3_01261384254. Viewer viewer;
	public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864._10_3_01261384254. _12_4_1929227091 _12_4_1929227091;
	public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864._10_3_01261384254._12_4_1929227091. _12_12_12043264204 _12_12_12043264204;

    public AbstractHtmlViewerExamplesMold(B box) {
        super(box);
        id("htmlViewerExamplesMold");
    }

    @Override
	public void init() {
		super.init();
		if (_7_1_1293588351 == null) _7_1_1293588351 = register(new _7_1_1293588351(box()).<_7_1_1293588351>id("a318037578").owner(AbstractHtmlViewerExamplesMold.this));
		if (_7_1_1293588351 != null) _8_2_0698354864 = _7_1_1293588351._8_2_0698354864;
		if (_8_2_0698354864 != null) _9_3_0308355687 = _7_1_1293588351._8_2_0698354864._9_3_0308355687;
		if (_8_2_0698354864 != null) _10_3_01261384254 = _7_1_1293588351._8_2_0698354864._10_3_01261384254;
		if (_10_3_01261384254 != null) viewer = _7_1_1293588351._8_2_0698354864._10_3_01261384254.viewer;
		if (_10_3_01261384254 != null) _12_4_1929227091 = _7_1_1293588351._8_2_0698354864._10_3_01261384254._12_4_1929227091;
		if (_12_4_1929227091 != null) _12_12_12043264204 = _7_1_1293588351._8_2_0698354864._10_3_01261384254._12_4_1929227091._12_12_12043264204;
	}

	public class _7_1_1293588351 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public HtmlViewerExamplesMold._7_1_1293588351. _8_2_0698354864 _8_2_0698354864;

		public _7_1_1293588351(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_8_2_0698354864 == null) _8_2_0698354864 = register(new _8_2_0698354864(box()).<_8_2_0698354864>id("a1923418852").owner(AbstractHtmlViewerExamplesMold.this));
		}

		public class _8_2_0698354864 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864. _9_3_0308355687 _9_3_0308355687;
			public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864. _10_3_01261384254 _10_3_01261384254;

			public _8_2_0698354864(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_9_3_0308355687 == null) _9_3_0308355687 = register(new _9_3_0308355687(box()).<_9_3_0308355687>id("a382813672").owner(AbstractHtmlViewerExamplesMold.this));
				if (_10_3_01261384254 == null) _10_3_01261384254 = register(new _10_3_01261384254(box()).<_10_3_01261384254>id("a1974655275").owner(AbstractHtmlViewerExamplesMold.this));
			}

			public class _9_3_0308355687 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _9_3_0308355687(B box) {
					super(box);
					_value("No facets");
				}

				@Override
				public void init() {
					super.init();
				}
			}

			public class _10_3_01261384254 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864._10_3_01261384254. Viewer viewer;
				public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864._10_3_01261384254. _12_4_1929227091 _12_4_1929227091;

				public _10_3_01261384254(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (viewer == null) viewer = register(new Viewer(box()).<Viewer>id("a1950596668").owner(AbstractHtmlViewerExamplesMold.this));
					if (_12_4_1929227091 == null) _12_4_1929227091 = register(new _12_4_1929227091(box()).<_12_4_1929227091>id("a1072838868").owner(AbstractHtmlViewerExamplesMold.this));
				}

				public class Viewer extends io.intino.alexandria.ui.displays.components.HtmlViewer<io.intino.alexandria.ui.displays.notifiers.HtmlViewerNotifier, B>  {

					public Viewer(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
					}
				}

				public class _12_4_1929227091 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
					public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864._10_3_01261384254._12_4_1929227091. _12_12_12043264204 _12_12_12043264204;

					public _12_4_1929227091(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
						if (_12_12_12043264204 == null) _12_12_12043264204 = register(new _12_12_12043264204(box()).<_12_12_12043264204>id("a_282852676").owner(AbstractHtmlViewerExamplesMold.this));
					}

					public class _12_12_12043264204 extends io.intino.alexandria.ui.displays.components.TextCode<io.intino.alexandria.ui.displays.notifiers.TextCodeNotifier, B>  {

						public _12_12_12043264204(B box) {
							super(box);
							_value("HtmlViewer(content=\"&lt;div style='font-weight:bold;background:black;color:white;padding:10px;margin:10px'&gt;Hello world!&lt;/div&gt;\")");
						}

						@Override
						public void init() {
							super.init();
						}
					}
				}
			}
		}
	}
}

==> ui-framework-4.17.9-sources.jar: io/intino/alexandria/ui/displays/templates/AbstractHtmlViewerExamplesMold.java <==
package io.intino.alexandria.ui.displays.templates;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.alexandria.ui.*;

import io.intino.alexandria.UiFrameworkBox;

import io.intino.alexandria.ui.displays.templates.*;






import io.intino.alexandria.ui.displays.items.*;
import io.intino.alexandria.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.TemplateNotifier;

public abstract class AbstractHtmlViewerExamplesMold<B extends Box> extends io.intino.alexandria.ui.displays.components.Template<TemplateNotifier, java.lang.Void, B> {
	public _7_1_1293588351 _7_1_1293588351;
	public HtmlViewerExamplesMold._7_1_1293588351. _8_2_0698354864 _8_2_0698354864;
	public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864. _9_3_0308355687 _9_3_0308355687;
	public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864. _10_3_01261384254 _10_3_01261384254;
	public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864._10_3_01261384254. Viewer viewer;
	public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864._10_3_01261384254. _12_4_1929227091 _12_4_1929227091;
	public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864._10_3_01261384254._12_4_1929227091. _12_12_12043264204 _12_12_12043264204;

    public AbstractHtmlViewerExamplesMold(B box) {
        super(box);
        id("htmlViewerExamplesMold");
    }

    @Override
	public void init() {
		super.init();
		if (_7_1_1293588351 == null) _7_1_1293588351 = register(new _7_1_1293588351(box()).<_7_1_1293588351>id("a318037578").owner(AbstractHtmlViewerExamplesMold.this));
		if (_7_1_1293588351 != null) _8_2_0698354864 = _7_1_1293588351._8_2_0698354864;
		if (_8_2_0698354864 != null) _9_3_0308355687 = _7_1_1293588351._8_2_0698354864._9_3_0308355687;
		if (_8_2_0698354864 != null) _10_3_01261384254 = _7_1_1293588351._8_2_0698354864._10_3_01261384254;
		if (_10_3_01261384254 != null) viewer = _7_1_1293588351._8_2_0698354864._10_3_01261384254.viewer;
		if (_10_3_01261384254 != null) _12_4_1929227091 = _7_1_1293588351._8_2_0698354864._10_3_01261384254._12_4_1929227091;
		if (_12_4_1929227091 != null) _12_12_12043264204 = _7_1_1293588351._8_2_0698354864._10_3_01261384254._12_4_1929227091._12_12_12043264204;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_7_1_1293588351 != null) _7_1_1293588351.unregister();
	}

	public class _7_1_1293588351 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
		public HtmlViewerExamplesMold._7_1_1293588351. _8_2_0698354864 _8_2_0698354864;

		public _7_1_1293588351(B box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (_8_2_0698354864 == null) _8_2_0698354864 = register(new _8_2_0698354864(box()).<_8_2_0698354864>id("a1923418852").owner(AbstractHtmlViewerExamplesMold.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (_8_2_0698354864 != null) _8_2_0698354864.unregister();
		}

		public class _8_2_0698354864 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
			public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864. _9_3_0308355687 _9_3_0308355687;
			public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864. _10_3_01261384254 _10_3_01261384254;

			public _8_2_0698354864(B box) {
				super(box);
			}

			@Override
			public void init() {
				super.init();
				if (_9_3_0308355687 == null) _9_3_0308355687 = register(new _9_3_0308355687(box()).<_9_3_0308355687>id("a382813672").owner(AbstractHtmlViewerExamplesMold.this));
				if (_10_3_01261384254 == null) _10_3_01261384254 = register(new _10_3_01261384254(box()).<_10_3_01261384254>id("a1974655275").owner(AbstractHtmlViewerExamplesMold.this));
			}

			@Override
			public void unregister() {
			    super.unregister();
				if (_9_3_0308355687 != null) _9_3_0308355687.unregister();
				if (_10_3_01261384254 != null) _10_3_01261384254.unregister();
			}

			public class _9_3_0308355687 extends io.intino.alexandria.ui.displays.components.Text<io.intino.alexandria.ui.displays.notifiers.TextNotifier, B>  {

				public _9_3_0308355687(B box) {
					super(box);
					_value("No facets");
				}

				@Override
				public void init() {
					super.init();
				}

				@Override
				public void unregister() {
				    super.unregister();
				}
			}

			public class _10_3_01261384254 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
				public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864._10_3_01261384254. Viewer viewer;
				public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864._10_3_01261384254. _12_4_1929227091 _12_4_1929227091;

				public _10_3_01261384254(B box) {
					super(box);
				}

				@Override
				public void init() {
					super.init();
					if (viewer == null) viewer = register(new Viewer(box()).<Viewer>id("a1950596668").owner(AbstractHtmlViewerExamplesMold.this));
					if (_12_4_1929227091 == null) _12_4_1929227091 = register(new _12_4_1929227091(box()).<_12_4_1929227091>id("a1072838868").owner(AbstractHtmlViewerExamplesMold.this));
				}

				@Override
				public void unregister() {
				    super.unregister();
					if (viewer != null) viewer.unregister();
					if (_12_4_1929227091 != null) _12_4_1929227091.unregister();
				}

				public class Viewer extends io.intino.alexandria.ui.displays.components.HtmlViewer<io.intino.alexandria.ui.displays.notifiers.HtmlViewerNotifier, B>  {

					public Viewer(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
					}

					@Override
					public void unregister() {
					    super.unregister();
					}
				}

				public class _12_4_1929227091 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, B>  {
					public HtmlViewerExamplesMold._7_1_1293588351._8_2_0698354864._10_3_01261384254._12_4_1929227091. _12_12_12043264204 _12_12_12043264204;

					public _12_4_1929227091(B box) {
						super(box);
					}

					@Override
					public void init() {
						super.init();
						if (_12_12_12043264204 == null) _12_12_12043264204 = register(new _12_12_12043264204(box()).<_12_12_12043264204>id("a_282852676").owner(AbstractHtmlViewerExamplesMold.this));
					}

					@Override
					public void unregister() {
					    super.unregister();
						if (_12_12_12043264204 != null) _12_12_12043264204.unregister();
					}

					public class _12_12_12043264204 extends io.intino.alexandria.ui.displays.components.TextCode<io.intino.alexandria.ui.displays.notifiers.TextCodeNotifier, B>  {

						public _12_12_12043264204(B box) {
							super(box);
							_value("HtmlViewer(content=\"&lt;div style='font-weight:bold;background:black;color:white;padding:10px;margin:10px'&gt;Hello world!&lt;/div&gt;\")");
						}

						@Override
						public void init() {
							super.init();
						}

						@Override
						public void unregister() {
						    super.unregister();
						}
					}
				}
			}
		}
	}
}
